@@ -10,3 +10,5 @@ class Action(Enum):
     ADD = auto()
     RENAME = auto()
     DELETE = auto()
+    RESET = auto()
+    RESET_REC = auto()
