@@ -1,17 +1,14 @@
 from rich.console import RenderableType
 from rich.text import Text
-from textual.reactive import Reactive
 from textual.widget import Widget
 
-from ..stopwatch import sec_to_str
-from .entry import Entry, generate_empty_entry
 from ..config import config
+from ..stopwatch import sec_to_str
+from ..timetuple import TimeTuple
+from .entry import Entry, generate_empty_entry
 
 
 class Total(Widget, can_focus=False):
-
-    _data: Reactive[Entry]
-
     def __init__(
         self,
         data: Entry = generate_empty_entry(-1, -1),
@@ -21,10 +18,11 @@ class Total(Widget, can_focus=False):
         self._data = data
 
     def render(self) -> RenderableType:
-        return Text().assemble(
-            f"Today: {sec_to_str(self._data.today)}   ",
-            f"Month: {sec_to_str(self._data.month)}   ",
-            f"Total: {sec_to_str(self._data.total)}",
+        time_str = TimeTuple(*map(sec_to_str, self._data.time))
+        return Text.assemble(
+            f"Today: {time_str.today}   ",
+            f"Month: {time_str.month}   ",
+            f"Total: {time_str.total}",
             style=config.styles["FOOTER"],
             justify="center",
         )
